@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use String::Charcount q/:all/;
+use String::Charcount qw(count percentage);
 
 my ($string, $count, $percentage);
  
