@@ -1,17 +1,15 @@
-# $Id: Charcount.pm,v 0.03 2004/01/15 21:55:37 sts Exp $
+# $Id: Charcount.pm,v 0.04 2004/01/15 21:55:37 sts Exp $
 
 package String::Charcount;
 
 use 5.006;
-use base(Exporter);
+use base qw(Exporter);
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our @EXPORT_OK = qw(count percentage);
-our %EXPORT_TAGS = (  all  =>    [ @EXPORT_OK ]
-);
 
 sub croak {
     require Carp;
@@ -24,7 +22,7 @@ String::Charcount - count the occurence of characters within a string.
 
 =head1 SYNOPSIS
 
- use String::Charcount q/:all/;
+ use String::Charcount qw(count percentage);
 
  $string = 'The lazy brown fox jumped over the cat sitting on the fence.';
 
@@ -48,7 +46,7 @@ Counts the occurence of all characters within a string.
  $count = count(\$string);
  print 'e exists ', $$count{e}, ' times',"\n";
 
-Returns an hash ref with characters as keys and 
+Returns an hashref with characters as keys and 
 occurences as values.
 
 =cut
@@ -74,7 +72,7 @@ all characters within a string.
  $percentage = percentage(\$string, $count);
  print 'e percentage - ', $$percentage{e}, '%',"\n";
 
-Returns an hash ref with characters as keys and 
+Returns an hashref with characters as keys and 
 percentages of occurence as values.
 
 =cut
@@ -82,8 +80,8 @@ percentages of occurence as values.
 sub percentage {
     my ($string, $count) = @_;
     croak q~usage: percentage (\$string, $count_ref)~
-      unless $$string && %$count && 
-      ref $string eq 'SCALAR' && ref $count eq 'HASH';
+      unless $$string && %$count 
+      && ref $string eq 'SCALAR' && ref $count eq 'HASH';
        
     my $perc_single = 100 / length $$string;
     
@@ -100,23 +98,6 @@ __END__
 
 =head1 EXPORT
 
-C<count(), percentage()> upon request.
-
-B<TAGS>
-
-C<:all - *()>
-
-=head1 SEE ALSO
-
-perl(1)
-
-=head1 LICENSE
-
-This program is free software; 
-you may redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Steven Schubiger
+C<count(), percentage()> are exportable.
 
 =cut
